@@ -22,6 +22,7 @@ except:
     version = __version__
 
 import colorlog
+
 logger = colorlog.getLogger("bioservices")
 
 
@@ -30,8 +31,8 @@ configuration = CustomConfig("bioservices", verbose=False)
 bspath = configuration.user_config_dir
 
 # Add bioservices.uniprot to sys.modules to prevent cycles in our imports
-#import bioservices.uniprot
-#bioservices.uniprot  # Stop flake8 error
+# import bioservices.uniprot
+# bioservices.uniprot  # Stop flake8 error
 
 from . import settings
 from .settings import *
@@ -48,6 +49,9 @@ from .biocarta import *
 from . import biomodels
 from .biomodels import *
 
+from . import biocontainers
+from .biocontainers import Biocontainers
+
 from . import cog
 from .cog import *
 
@@ -64,8 +68,8 @@ from . import ensembl
 from .ensembl import *
 
 # moved to attic in bioservices v1.6
-#from . import geneprof
-#from .geneprof import *
+# from . import geneprof
+# from .geneprof import *
 
 from . import kegg
 from .kegg import *
@@ -122,8 +126,8 @@ from .quickgo import *
 from . import chembl
 from .chembl import *
 
-#from . import picr
-#from .picr import *
+# from . import picr
+# from .picr import *
 
 from . import psicquic
 from .psicquic import *
@@ -131,8 +135,8 @@ from .psicquic import *
 from . import ncbiblast
 from .ncbiblast import *
 
-#from . import readseq
-#from .readseq import *
+# from . import readseq
+# from .readseq import *
 
 from . import biogrid
 from .biogrid import *
@@ -163,7 +167,7 @@ from .omicsdi import OmicsDI
 
 # sub packages inside bioservices.
 
-#import mapping
+# import mapping
 from . import apps
-#import dev
 
+# import dev
