@@ -27,6 +27,7 @@ from bioservices._compat import string_types, iteritems
 
 __all__ = ["OmicsDI"]
 
+
 def _omicsdi_path_to_method_name(path):
     # strip leading and trailing "/"
     formatted = path.strip("/")
@@ -41,10 +42,13 @@ def _omicsdi_path_to_method_name(path):
 
     return method_name
 
+
 class OmicsDIAuth(requests.auth.AuthBase):
     def __init__(self, token):
         if not isinstance(token, string_types):
-            raise TypeError("Authentication Token cannot be %s. Must be of type str." % token)
+            raise TypeError(
+                "Authentication Token cannot be %s. Must be of type str." % token
+            )
 
         self._token = token
 
@@ -65,15 +69,17 @@ class OmicsDIAuth(requests.auth.AuthBase):
         r.headers["x-auth-token"] = self._token
         return r
 
+
 class OmicsDI(REST):
     _url = "http://www.omicsdi.org/ws"
     _api = {
-        "paths": [{
-            "path": "/dataset/merge",
-            "method": "POST",
-            "params": "mergeCandidate",
-            "auth": True,
-            "doc": """
+        "paths": [
+            {
+                "path": "/dataset/merge",
+                "method": "POST",
+                "params": "mergeCandidate",
+                "auth": True,
+                "doc": """
                 Merge datasets
 
                 :example:
@@ -81,12 +87,13 @@ class OmicsDI(REST):
                     >>> omicsdi = OmicsDI()
                     >>> omicsdi.set_auth_token("<YOUR_AUTH_TOKEN>")
                     >>> omicsdi.dataset_merge()
-            """
-        }, {
-            "path": "/dataset/getMergeCandidates",
-            "params": ["start", "size"],
-            "auth": True,
-            "doc": """
+            """,
+            },
+            {
+                "path": "/dataset/getMergeCandidates",
+                "params": ["start", "size"],
+                "auth": True,
+                "doc": """
                 Retrieve merge candidates
 
                 :example:
@@ -94,23 +101,17 @@ class OmicsDI(REST):
                     >>> omicsdi = OmicsDI()
                     >>> omicsdi.set_auth_token("<YOUR_AUTH_TOKEN>")
                     >>> omicsdi.dataset_get_merge_candidates(start = 0, size = 20)
-            """
-        }, {
-            "path": "/dataset/:domain/:acc/files",
-            "function_name": "dataset_domain_accession_files",
-            "params": {
-                "domain": {
-                    "type": "path"
-                },
-                "acc": {
-                    "type": "path",
-                    "argument": "accession"
-                },
-                "position": {
-                    "required": True
-                }
+            """,
             },
-            "doc": """
+            {
+                "path": "/dataset/:domain/:acc/files",
+                "function_name": "dataset_domain_accession_files",
+                "params": {
+                    "domain": {"type": "path"},
+                    "acc": {"type": "path", "argument": "accession"},
+                    "position": {"required": True},
+                },
+                "doc": """
                 Get Files At
 
                 :example:
@@ -120,11 +121,12 @@ class OmicsDI(REST):
                         domain = "pride", position = 1)
                     [{'type': 'other',
                     'url': 'ftp://ftp.pride.ebi.ac.uk/pride/data/archive/2013/11/PXD000210/F049708.dat'}]
-            """
-        }, {
-            "path": "/dataset/search",
-            "params": ["query", "sortfield", "order", "start", "size", "faceCount"],
-            "doc": """
+            """,
+            },
+            {
+                "path": "/dataset/search",
+                "params": ["query", "sortfield", "order", "start", "size", "faceCount"],
+                "doc": """
                 Retrieve datasets in the resource using different queries
 
                 :example:
@@ -136,11 +138,12 @@ class OmicsDI(REST):
                     'source': 'arrayexpress-repository',
                     'title': 'Transcription profiling by array of human SHSY5Y cells transfected with miR96 and treated with methamphetamine',
                     'description': 'SHSY5Y cells trasnfected ±miR96 ± METH',...
-            """
-        }, {
-            "path": "/dataset/latest",
-            "params": "size",
-            "doc": """
+            """,
+            },
+            {
+                "path": "/dataset/latest",
+                "params": "size",
+                "doc": """
                 Retrieve the latest datasets in the repository
 
                 :example:
@@ -151,19 +154,15 @@ class OmicsDI(REST):
                     'datasets': [{'id': 'E-MTAB-8031',
                     'source': 'arrayexpress-repository',
                     'title': 'An integrated approach to profile lung tumor endothelial cell heterogeneity across species and models and to identify angiogenic candidates',
-            """
-        }, {
-            "path": "/dataset/batch",
-            "params": {
-                "accession": {
-                    "required": True,
-                    "argument": "accession"
-                },
-                "database": {
-                    "required": True
-                }
+            """,
             },
-            "doc": """
+            {
+                "path": "/dataset/batch",
+                "params": {
+                    "accession": {"required": True, "argument": "accession"},
+                    "database": {"required": True},
+                },
+                "doc": """
                 Retrieve an specific dataset
 
                 :example:
@@ -174,15 +173,12 @@ class OmicsDI(REST):
                     'datasets': [{'id': 'PXD000210',
                     'source': 'pride',
                     'name': 'Proteome analysis by charge state-selective separation of peptides: a multidimensional approach',...
-            """
-        }, {
-            "path": "/dataset/mostAccessed",
-            "params": {
-                "size": {
-                    "required": True
-                }
+            """,
             },
-            "doc": """
+            {
+                "path": "/dataset/mostAccessed",
+                "params": {"size": {"required": True}},
+                "doc": """
                 Retrieve a specific dataset
 
                 :example:
@@ -193,19 +189,15 @@ class OmicsDI(REST):
                     'datasets': [{'id': 'BIOMD0000000048',
                     'source': 'biomodels',
                     'title': 'Kholodenko1999 - EGFR signaling',...
-            """
-        }, {
-            "path": "/dataset/getFileLinks",
-            "params": {
-                "accession": {
-                    "required": True,
-                    "argument": "accession"
-                },
-                "database": {
-                    "required": True
-                },
+            """,
             },
-            "doc": """
+            {
+                "path": "/dataset/getFileLinks",
+                "params": {
+                    "accession": {"required": True, "argument": "accession"},
+                    "database": {"required": True},
+                },
+                "doc": """
                 Retrieve all file links for a given dataset
 
                 :example:
@@ -215,23 +207,17 @@ class OmicsDI(REST):
                     [
                         "ftp://ftp.pride.ebi.ac.uk/pride/data/archive/2013/11/PXD000210/L9822_0872_Lazaro_100812_RH1_MEF_9.RAW",
                         "ftp://ftp.pride.ebi.ac.uk/pride/data/archive/2013/11/PXD000210/R8798_Lazaro_RH2_ETD_10.RAW",...
-            """
-        }, {
-            "path": "/dataset/:domain/:acc",
-            "function_name": "dataset_domain_accession",
-            "params": {
-                "domain": {
-                    "type": "path"
-                },
-                "acc": {
-                    "type": "path",
-                    "argument": "accession"
-                },
-                "debug": {
-                    "default": False
-                }
+            """,
             },
-            "doc": """
+            {
+                "path": "/dataset/:domain/:acc",
+                "function_name": "dataset_domain_accession",
+                "params": {
+                    "domain": {"type": "path"},
+                    "acc": {"type": "path", "argument": "accession"},
+                    "debug": {"default": False},
+                },
+                "doc": """
                 Get Files At
 
                 :example:
@@ -246,19 +232,15 @@ class OmicsDI(REST):
                             "Xlsx": [
                                 "ftp://ftp.pride.ebi.ac.uk/pride/data/archive/2013/11/PXD000210/identifications RH2 - ETD.xlsx"
                             ],...
-            """
-        }, {
-            "path": "/dataset/getSimilar",
-            "params": {
-                "accession": {
-                    "required": True,
-                    "argument": "accession"
-                },
-                "database": {
-                    "required": True
-                }
+            """,
             },
-            "doc": """
+            {
+                "path": "/dataset/getSimilar",
+                "params": {
+                    "accession": {"required": True, "argument": "accession"},
+                    "database": {"required": True},
+                },
+                "doc": """
                 Retrieve the related datasets to one Dataset
 
                 :example:
@@ -272,15 +254,12 @@ class OmicsDI(REST):
                             "id": "E-PROT-2",
                             "source": "arrayexpress-repository",
                             "title": "Proteomic profiling of NCI60 cell lines from Cancer Cell Line Encyclopedia",...
-            """
-        }, {
-            "path": "/dataset/getSimilarByPubmed",
-            "params": {
-                "pubmed": {
-                    "required": True
-                }
+            """,
             },
-            "doc": """
+            {
+                "path": "/dataset/getSimilarByPubmed",
+                "params": {"pubmed": {"required": True}},
+                "doc": """
                 Retrieve all datasets which have same pubmed id
 
                 :example:
@@ -292,10 +271,11 @@ class OmicsDI(REST):
                             "accession": "E-TIGR-123",
                             "database": "ArrayExpress",
                             "initHashCode": -642128312,...
-            """
-        }, {
-            "path": "/database/all",
-            "doc": """
+            """,
+            },
+            {
+                "path": "/database/all",
+                "doc": """
                 Get DataBase List
 
                 :example:
@@ -308,16 +288,12 @@ class OmicsDI(REST):
                             "title": "EGA Database",
                             "sourceUrl": "https://ega-archive.org",
                             "imgAlt": "EGA logo",...
-            """
-        }, {
-            "path": "/term/getTermByPattern",
-            "params": {
-                "q": {
-                    "argument": "query"
-                },
-                "size": { }
+            """,
             },
-            "doc": """
+            {
+                "path": "/term/getTermByPattern",
+                "params": {"q": {"argument": "query"}, "size": {}},
+                "doc": """
                 Retrieve the Terms for a pattern
 
                 :example:
@@ -328,19 +304,18 @@ class OmicsDI(REST):
                         "total_count": 0,
                         "items": []
                     }
-            """
-        }, {
-            "path": "/term/frequentlyTerm/list",
-            "params": {
-                "size": { },
-                "domain": {
-                    "required": True,
-                },
-                "field": {
-                    "required": True
-                }
+            """,
             },
-            "doc": """
+            {
+                "path": "/term/frequentlyTerm/list",
+                "params": {
+                    "size": {},
+                    "domain": {
+                        "required": True,
+                    },
+                    "field": {"required": True},
+                },
+                "doc": """
                 Retrieve frequently terms from the Repo
 
                 :example:
@@ -352,10 +327,11 @@ class OmicsDI(REST):
                             "label": "analysis",
                             "frequent": "2770"
                         },...
-            """
-        }, {
-            "path": "/seo/home",
-            "doc": """
+            """,
+            },
+            {
+                "path": "/seo/home",
+                "doc": """
                 Retrieve data for home page
 
                 :example:
@@ -367,10 +343,11 @@ class OmicsDI(REST):
                             {
                             "name": "Omics Discovery Index - Discovering and Linking Public Omics Datasets",
                             "url": "http://www.omicsdi.org/",...
-            """
-        }, {
-            "path": "/seo/search",
-            "doc": """
+            """,
+            },
+            {
+                "path": "/seo/search",
+                "doc": """
                 Retrieve data for browse page
 
                 :example:
@@ -381,10 +358,11 @@ class OmicsDI(REST):
                         "name": "Browse",
                         "url": "http://www.omicsdi.org/search?q=*:*",
                         "keywords": "OmicsDI, Search, Browsers, Datasets, Searching",...
-            """
-        }, {
-            "path": "/seo/api",
-            "doc": """
+            """,
+            },
+            {
+                "path": "/seo/api",
+                "doc": """
                 Retrieve data for api page
 
                 :example:
@@ -395,10 +373,11 @@ class OmicsDI(REST):
                         "name": "API",
                         "url": "http://www.omicsdi.org/api",
                         "keywords": "OmicsDI About Page, Help, Consortium",...
-            """
-        }, {
-            "path": "/seo/database",
-            "doc": """
+            """,
+            },
+            {
+                "path": "/seo/database",
+                "doc": """
                 Retrieve data for databases page
 
                 :example:
@@ -409,22 +388,16 @@ class OmicsDI(REST):
                         "name": "Databases",
                         "url": "http://www.omicsdi.org/database",
                         "keywords": "OmicsDI Help Page, Training, Examples",...
-            """
-        }, {
-            "path": "/seo/dataset/:domain/:acc",
-            "function_name": "seo_dataset_domain_accession",
-            "params": {
-                "domain": {
-                    "type": "path",
-                    "required": True
-                },
-                "acc": {
-                    "type": "path",
-                    "required": True,
-                    "argument": "accession"
-                }
+            """,
             },
-            "doc": """
+            {
+                "path": "/seo/dataset/:domain/:acc",
+                "function_name": "seo_dataset_domain_accession",
+                "params": {
+                    "domain": {"type": "path", "required": True},
+                    "acc": {"type": "path", "required": True, "argument": "accession"},
+                },
+                "doc": """
                 Retrieve data for dataset page
 
                 :example:
@@ -436,10 +409,11 @@ class OmicsDI(REST):
                         "url": null,
                         "keywords": "Mouse,SCX,RP-HPLC basic pH,LC-MSMS",...
 
-            """
-        }, {
-            "path": "/seo/about",
-            "doc": """
+            """,
+            },
+            {
+                "path": "/seo/about",
+                "doc": """
                 Retrieve data for about page
 
                 :example:
@@ -450,11 +424,12 @@ class OmicsDI(REST):
                         "name": "About OmicsDI",
                         "url": "http://www.omicsdi.org/about",
                         "keywords": "OmicsDI About Page, Help, Consortium",...
-            """
-        }, {
-            "path": "/statistics/organisms",
-            "params": "size",
-            "doc": """
+            """,
+            },
+            {
+                "path": "/statistics/organisms",
+                "params": "size",
+                "doc": """
                 Return statistics about the number of datasets per Organisms
 
                 :example:
@@ -468,11 +443,12 @@ class OmicsDI(REST):
                             "value": "443401",
                             "name": "Total"
                         },...
-            """
-        }, {
-            "path": "/statistics/tissues",
-            "params": "size",
-            "doc": """
+            """,
+            },
+            {
+                "path": "/statistics/tissues",
+                "params": "size",
+                "doc": """
                 Return statistics about the number of datasets per Tissue
 
                 :example:
@@ -482,10 +458,11 @@ class OmicsDI(REST):
                     [{'label': 'Total', 'id': None, 'value': '443401', 'name': 'Total'},
                     {'label': 'Liver', 'id': 'Liver', 'value': '135', 'name': 'Liver'},
                     {'label': 'Kidney', 'id': 'Kidney', 'value': '65', 'name': 'Kidney'},...
-            """
-        }, {
-            "path": "/statistics/omics",
-            "doc": """
+            """,
+            },
+            {
+                "path": "/statistics/omics",
+                "doc": """
                 Return statistics about the number of datasets per Omics Type
 
                 :example:
@@ -497,10 +474,11 @@ class OmicsDI(REST):
                     'id': 'Transcriptomics',
                     'value': '126876',
                     'name': 'Transcriptomics'},...
-            """
-        }, {
-            "path": "/statistics/diseases",
-            "doc": """
+            """,
+            },
+            {
+                "path": "/statistics/diseases",
+                "doc": """
                 Return statistics about the number of datasets per diseases
 
                 :example:
@@ -513,10 +491,11 @@ class OmicsDI(REST):
                     'id': 'Breast Cancer',
                     'value': '54',
                     'name': 'Breast Cancer'},...
-            """
-        }, {
-            "path": "/statistics/domains",
-            "doc": """
+            """,
+            },
+            {
+                "path": "/statistics/domains",
+                "doc": """
                 Return statistics about the number of datasets per Repository
 
                 :example:
@@ -528,10 +507,11 @@ class OmicsDI(REST):
                     'value': '72617',
                     'name': 'ArrayExpress'},
                     'subdomains': []},...
-            """
-        }, {
-            "path": "/statistics/omicsByYear",
-            "doc": """
+            """,
+            },
+            {
+                "path": "/statistics/omicsByYear",
+                "doc": """
                 Return statistics about the number of datasets per OmicsType on recent 5 years.
 
                 :example:
@@ -539,13 +519,16 @@ class OmicsDI(REST):
                     >>> omicsdi = OmicsDI()
                     >>> omicsdi.statistics_omics_by_year()
                     [{'year': '2020', 'genomics': '26', 'metabolomics': '41', 'proteomics': '11', 'transcriptomics': '223'}, {'year': '2019', 'genomics': '170', 'metabolomics': '578', 'proteomics': '1779', 'transcriptomics': '927'}, {'year': '2018', 'genomics': '594', 'metabolomics': '678', 'proteomics': '2646', 'transcriptomics': '1609'}, {'year': '2017', 'genomics': '127', 'metabolomics': '716', 'proteomics': '1969', 'transcriptomics': '1015'}]
-            """
-        }]
+            """,
+            },
+        ]
     }
 
     def __init__(self, token=None, verbose=False, cache=False):
-        self.super  = super(OmicsDI, self)
-        self.super.__init__(name="OmicsDI", url=OmicsDI._url, verbose=verbose, cache=cache)
+        self.super = super(OmicsDI, self)
+        self.super.__init__(
+            name="OmicsDI", url=OmicsDI._url, verbose=verbose, cache=cache
+        )
 
         self.set_auth_token(token)
 
@@ -568,13 +551,17 @@ class OmicsDI(REST):
         self.token = token
 
     def _create_api_function(self, api):
-        METHOD_CALLERS = { "GET": self.http_get, "POST": self.http_post,
-            "PUT": self.http_put, "DELETE": self.http_delete }
+        METHOD_CALLERS = {
+            "GET": self.http_get,
+            "POST": self.http_post,
+            "PUT": self.http_put,
+            "DELETE": self.http_delete,
+        }
 
         doc = api.get("doc")
 
         def fn(*args, **kwargs):
-            data = { }
+            data = {}
 
             query = api["path"]
             params = api.get("params")
@@ -582,7 +569,7 @@ class OmicsDI(REST):
             auth_required = api.get("auth", False)
 
             if params:
-                parameters = [ ]
+                parameters = []
 
                 if isinstance(params, collections.Mapping):
                     for param, info in iteritems(params):
@@ -607,11 +594,11 @@ class OmicsDI(REST):
                         value = kwargs.get(parameter)
                         data[parameter] = value
 
-            args = { "params": data , "frmt": "json"}
+            args = {"params": data, "frmt": "json"}
 
             if auth_required:
-                auth = OmicsDIAuth(token = self.token)
-                args.update({ "auth": auth })
+                auth = OmicsDIAuth(token=self.token)
+                args.update({"auth": auth})
 
             method_caller = METHOD_CALLERS.get(method, self.http_get)
 
@@ -628,7 +615,6 @@ class OmicsDI(REST):
 
             fn = self._create_api_function(api)
 
-            method_name = api.get("function_name",
-                _omicsdi_path_to_method_name(query))
+            method_name = api.get("function_name", _omicsdi_path_to_method_name(query))
 
             setattr(self, method_name, fn)
