@@ -40,7 +40,7 @@ from bioservices.services import REST
 __all__ = ["PDBe"]
 
 
-class PDBe():
+class PDBe:
     """Interface to part of the `PDBe <http://www.ebi.ac.uk/pdbe>`_ service
 
     .. doctest::
@@ -68,7 +68,9 @@ class PDBe():
             for item in pdbid.split(","):
                 assert len(item) == 4, "a 4-character PDB id code is required"
         else:
-            raise TypeError("pdb id must be either a 4-character pdb id, a list of valid PDB ids, or a string made of pdb ids, separated by commas")
+            raise TypeError(
+                "pdb id must be either a 4-character pdb id, a list of valid PDB ids, or a string made of pdb ids, separated by commas"
+            )
 
         return pdbid
 
@@ -97,8 +99,7 @@ class PDBe():
         if isinstance(query, str) and "," not in query:
             res = self.services.http_get("summary/{}".format(query))
         else:
-            res = self.services.http_post("summary", 
-                data=query, frmt="json")
+            res = self.services.http_post("summary", data=query, frmt="json")
         return self._return(res)
 
     def get_molecules(self, query):
@@ -119,8 +120,7 @@ class PDBe():
         if isinstance(query, str) and "," not in query:
             res = self.services.http_get("molecules/{}".format(query))
         else:
-            res = self.services.http_post("molecules",
-                data=query, frmt="json")
+            res = self.services.http_post("molecules", data=query, frmt="json")
         return self._return(res)
 
     def get_related_publications(self, query):
@@ -143,8 +143,9 @@ class PDBe():
         if isinstance(query, str) and "," not in query:
             res = self.services.http_get("related_publications/{}".format(query))
         else:
-            res = self.services.http_post("related_publications/",
-                data=query, frmt="json")
+            res = self.services.http_post(
+                "related_publications/", data=query, frmt="json"
+            )
         return self._return(res)
 
     def get_experiment(self, query):
@@ -169,8 +170,7 @@ class PDBe():
         if isinstance(query, str) and "," not in query:
             res = self.services.http_get("experiment/{}".format(query))
         else:
-            res = self.services.http_post("experiment/{}",
-                data=query, frmt="json")
+            res = self.services.http_post("experiment/{}", data=query, frmt="json")
         return self._return(res)
 
     def get_nmr_resources(self, query):
@@ -188,11 +188,9 @@ class PDBe():
         if isinstance(query, str) and "," not in query:
             res = self.services.http_get("nmr_resources/{}".format(query))
         else:
-            res = self.services.http_post("nmr_resources/", 
-                data=query, frmt="json")
+            res = self.services.http_post("nmr_resources/", data=query, frmt="json")
         return self._return(res)
 
-
     def get_ligand_monomers(self, query):
         """Provides a a list of modelled instances of ligands,
 
@@ -210,8 +208,7 @@ class PDBe():
         if isinstance(query, str) and "," not in query:
             res = self.services.http_get("ligand_monomers/{}".format(query))
         else:
-            res = self.services.http_post("ligand_monomers", 
-                data=query, frmt="json")
+            res = self.services.http_post("ligand_monomers", data=query, frmt="json")
         return self._return(res)
 
     def get_modified_residues(self, query):
@@ -231,8 +228,7 @@ class PDBe():
         if isinstance(query, str) and "," not in query:
             res = self.services.http_get("modified_AA_or_NA/{}".format(query))
         else:
-            res = self.services.http_post("modified_AA_or_NA", 
-                data=query, frmt="json")
+            res = self.services.http_post("modified_AA_or_NA", data=query, frmt="json")
         return self._return(res)
 
     def get_mutated_residues(self, query):
@@ -252,8 +248,7 @@ class PDBe():
         if isinstance(query, str) and "," not in query:
             res = self.services.http_get("mutated_AA_or_NA/{}".format(query))
         else:
-            res = self.services.http_get("mutated_AA_or_NA",
-                data=query, frmt="json")
+            res = self.services.http_get("mutated_AA_or_NA", data=query, frmt="json")
         return self._return(res)
 
     def get_release_status(self, query):
@@ -273,8 +268,7 @@ class PDBe():
         if isinstance(query, str) and "," not in query:
             res = self.services.http_get("status/{}".format(query))
         else:
-            res = self.services.http_get("status/{}", 
-                data=query, frmt="json")
+            res = self.services.http_get("status/{}", data=query, frmt="json")
         return self._return(res)
 
     def get_observed_ranges(self, query):
@@ -293,10 +287,9 @@ class PDBe():
         if isinstance(query, str) and "," not in query:
             res = self.services.http_get("polymer_coverage/{}".format(query))
         else:
-            res = self.services.http_post("polymer_coverage",
-                data=query, frmt="json")
+            res = self.services.http_post("polymer_coverage", data=query, frmt="json")
         return self._return(res)
-    
+
     def get_observed_ranges_in_pdb_chain(self, query, chain_id):
         """Provides observed ranges, i.e., segments of structural coverage of
          polymeric molecules in a particular chain
@@ -312,11 +305,12 @@ class PDBe():
         """
         assert len(query) == 4, "a 4-character PDB id code is required"
         res = self.services.http_get(
-            "polymer_coverage/{}/chain/{}".format(query, chain_id))
+            "polymer_coverage/{}/chain/{}".format(query, chain_id)
+        )
         return self._return(res)
 
     def get_secondary_structure(self, query):
-        """Provides residue ranges of regular secondary structure 
+        """Provides residue ranges of regular secondary structure
 
         (alpha helices and beta strands) found in protein chains of the entry.
         For strands, sheet id can be used to identify a beta sheet.
@@ -333,16 +327,16 @@ class PDBe():
         """
         query = self._check_id(query)
         if isinstance(query, str) and "," not in query:
-            res = self.services.http_get(
-                "secondary_structure/{}".format(query))
+            res = self.services.http_get("secondary_structure/{}".format(query))
         else:
-            res = self.services.http_post("secondary_structure/", 
-                data=query, frmt="json")
+            res = self.services.http_post(
+                "secondary_structure/", data=query, frmt="json"
+            )
         return self._return(res)
 
     def get_residue_listing(self, query):
         """Provides lists all residues (modelled or otherwise) in the entry.
-    
+
         Except waters, along with details of the fraction of expected atoms modelled for
         the residue and any alternate conformers.
 
@@ -357,14 +351,13 @@ class PDBe():
         """
         assert len(query) == 4, "a 4-character PDB id code is required"
         if isinstance(query, str) and "," not in query:
-            res = self.services.http_get(
-                "residue_listing/{}".format(query))
+            res = self.services.http_get("residue_listing/{}".format(query))
         return self._return(res)
 
     def get_residue_listing_in_pdb_chain(self, query, chain_id):
         """Provides all residues (modelled or otherwise) in the entry
 
-        Except waters, along with details of the fraction of expected atoms 
+        Except waters, along with details of the fraction of expected atoms
         modelled for the residue and any alternate conformers.
 
         :param query: a 4-character PDB id code
@@ -378,8 +371,7 @@ class PDBe():
         """
         assert len(query) == 4, "a 4-character PDB id code is required"
         if isinstance(query, str) and "," not in query:
-            res = self.services.http_get(
-                "residue_listing/{}".format(query, chain_id))
+            res = self.services.http_get("residue_listing/{}".format(query, chain_id))
         return self._return(res)
 
     def get_binding_sites(self, query):
@@ -399,19 +391,17 @@ class PDBe():
         """
         query = self._check_id(query)
         if isinstance(query, str) and "," not in query:
-            res = self.services.http_get(
-                "binding_sites/{}".format(query))
+            res = self.services.http_get("binding_sites/{}".format(query))
         else:
-            res = self.services.http_post("binding_sites", 
-                data=query, frmt="json")
+            res = self.services.http_post("binding_sites", data=query, frmt="json")
         return self._return(res)
-    
+
     def get_files(self, query):
         """Provides URLs and brief descriptions (labels) for PDB entry
 
-        Also, for mmcif files, biological assembly files, FASTA file for sequences, 
-        SIFTS cross reference XML files, validation XML files, X-ray structure 
-        factor file, NMR experimental constraints files, etc. 
+        Also, for mmcif files, biological assembly files, FASTA file for sequences,
+        SIFTS cross reference XML files, validation XML files, X-ray structure
+        factor file, NMR experimental constraints files, etc.
 
         :param query: a 4-character PDB id code
 
@@ -423,13 +413,11 @@ class PDBe():
         """
         query = self._check_id(query)
         if isinstance(query, str) and "," not in query:
-            res = self.services.http_get(
-                "files/{}".format(query))
+            res = self.services.http_get("files/{}".format(query))
         else:
-            res = self.services.http_post("files", 
-                data=query, frmt="json")
+            res = self.services.http_post("files", data=query, frmt="json")
         return self._return(res)
-    
+
     def get_observed_residues_ratio(self, query):
         """Provides the ratio of observed residues for each chain in each molecule
 
@@ -446,11 +434,11 @@ class PDBe():
         """
         query = self._check_id(query)
         if isinstance(query, str) and "," not in query:
-            res = self.services.http_get(
-                "observed_residues_ratio/{}".format(query))
+            res = self.services.http_get("observed_residues_ratio/{}".format(query))
         else:
-            res = self.services.http_post("observed_residues_ratio", 
-                data=query, frmt="json")
+            res = self.services.http_post(
+                "observed_residues_ratio", data=query, frmt="json"
+            )
         return self._return(res)
 
     def get_assembly(self, query):
@@ -470,11 +458,9 @@ class PDBe():
         """
         query = self._check_id(query)
         if isinstance(query, str) and "," not in query:
-            res = self.services.http_get(
-                "assembly/{}".format(query))
+            res = self.services.http_get("assembly/{}".format(query))
         else:
-            res = self.services.http_post("assembly", 
-                data=query, frmt="json")
+            res = self.services.http_post("assembly", data=query, frmt="json")
         return self._return(res)
 
     def get_electron_density_statistics(self, query):
@@ -490,13 +476,13 @@ class PDBe():
         """
         query = self._check_id(query)
         if isinstance(query, str) and "," not in query:
-            res = self.services.http_get(
-                "electron_density_statistics/{}".format(query))
+            res = self.services.http_get("electron_density_statistics/{}".format(query))
         else:
-            res = self.services.http_post("electron_density_statistics", 
-                data=query, frmt="json")
+            res = self.services.http_post(
+                "electron_density_statistics", data=query, frmt="json"
+            )
         return self._return(res)
-    
+
     def get_functional_annotation(self, query):
         """Provides functional annotation of all ligands, i.e. 'bound'
 
@@ -510,13 +496,11 @@ class PDBe():
         """
         query = self._check_id(query)
         if isinstance(query, str) and "," not in query:
-            res = self.services.http_get(
-                "cofactor/{}".format(query))
+            res = self.services.http_get("cofactor/{}".format(query))
         else:
-            res = self.services.http_post("cofactor", 
-                data=query, frmt="json")
+            res = self.services.http_post("cofactor", data=query, frmt="json")
         return self._return(res)
-    
+
     def get_drugbank_annotation(self, query):
         """This call provides DrugBank annotation of all ligands, i.e. 'bound'
 
@@ -530,11 +514,9 @@ class PDBe():
         """
         query = self._check_id(query)
         if isinstance(query, str) and "," not in query:
-            res = self.services.http_get(
-                "drugbank/{}".format(query))
+            res = self.services.http_get("drugbank/{}".format(query))
         else:
-            res = self.services.http_post("drugbank", 
-                data=query, frmt="json")
+            res = self.services.http_post("drugbank", data=query, frmt="json")
         return self._return(res)
 
     def get_related_dataset(self, query):
@@ -554,9 +536,9 @@ class PDBe():
         """
         query = self._check_id(query)
         if isinstance(query, str) and "," not in query:
-            res = self.services.http_get(
-                "related_experiment_data/{}".format(query))
+            res = self.services.http_get("related_experiment_data/{}".format(query))
         else:
-            res = self.services.http_post("related_experiment_data", 
-                data=query, frmt="json")
+            res = self.services.http_post(
+                "related_experiment_data", data=query, frmt="json"
+            )
         return self._return(res)
